@@ -2,7 +2,7 @@ package FBP::Choice;
 
 use Mouse;
 
-our $VERSION = '0.09';
+our $VERSION = '0.10';
 
 extends 'FBP::Window';
 with    'FBP::Control';
@@ -13,4 +13,9 @@ has selection => (
 	required => 1,
 );
 
+has OnChoice => (
+	is       => 'ro',
+	isa      => 'Str',
+);
+
 1;
